@@ -36,13 +36,16 @@ class Model:
         return name
 
 
-    @classmethod
-    def clone(cls, name=''):
-        class cln(cls):
-            pass
-        cln.__name__ = name if name else cls.__name__
-        cln.schema = clone(cls.schema)
-        cln.children_model_classes = clone(cls.children_model_classes)
+    @staticmethod
+    def extends(*classes, name=''):
+        class cln(*classes):
+            schema = {}
+            children_model_classes = {}
+        for cls in classes:
+            cln.schema |= clone(cls.schema)
+            cln.children_model_classes |= clone(cls.children_model_classes)
+            cln.__name__ = cls.__name__
+        if name: cln.__name__ = name
         return cln
 
 
@@ -148,6 +151,7 @@ class Model:
         if 'children' not in self.attrs:
             self.children = {}
         for col_id, model_cls in self.children_classes:
+            # read 'default_children' and load them
             child_model = model_cls.create(self.db)
             self.append_child(col_id, child_model)
 
@@ -239,7 +243,9 @@ class Model:
         for k, v in schema.items():
             if v['type'] in types_map:
                 t = 'ID' if k == 'id' else types_map[v['type']]
-                req = '!' if 'required' in v and v['required'] else ''
+                req = ''
+                if ('required' in v and v['required']) or ('default' in v):
+                    req = '!'
                 schema_str += f'    {k}: {t}{req}\n'
         return schema_str
 
@@ -251,7 +257,7 @@ class Model:
         schema_str += Model.graphql_fields(cls.schema)
         for c_id, child in cls.children_model_classes.items():
             child_cls = child['class']
-            quantity = child['quantity']
+            quantity = child['quantity'][0]
             ob = '[' if quantity == '*' or quantity == '+' else ''
             cb = ']' if ob else ''
             req = '!' if quantity == '+' or quantity == '1' else ''
